==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/ListSubscribedRuleGroupsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListSubscribedRuleGroupsResponse(
    nextMarker: Option[NextMarker] = None,
    ruleGroups: Option[Iterable[zio.aws.waf.model.SubscribedRuleGroupSummary]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse = {
    import ListSubscribedRuleGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        ruleGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ruleGroups)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly =
    zio.aws.waf.model.ListSubscribedRuleGroupsResponse.wrap(buildAwsValue())
}
object ListSubscribedRuleGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListSubscribedRuleGroupsResponse =
      zio.aws.waf.model.ListSubscribedRuleGroupsResponse(
        nextMarker.map(value => value),
        ruleGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Option[NextMarker]
    def ruleGroups
        : Option[List[zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getRuleGroups: ZIO[Any, AwsError, List[
      zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("ruleGroups", ruleGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ) extends zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val ruleGroups
        : Option[List[zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly]] =
      scala
        .Option(impl.ruleGroups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.waf.model.SubscribedRuleGroupSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ): zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/ListSubscribedRuleGroupsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListSubscribedRuleGroupsResponse(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    ruleGroups: Optional[
      Iterable[zio.aws.waf.model.SubscribedRuleGroupSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse = {
    import ListSubscribedRuleGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        ruleGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ruleGroups)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly =
    zio.aws.waf.model.ListSubscribedRuleGroupsResponse.wrap(buildAwsValue())
}
object ListSubscribedRuleGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListSubscribedRuleGroupsResponse =
      zio.aws.waf.model.ListSubscribedRuleGroupsResponse(
        nextMarker.map(value => value),
        ruleGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Optional[NextMarker]
    def ruleGroups
        : Optional[List[zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getRuleGroups: ZIO[Any, AwsError, List[
      zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("ruleGroups", ruleGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ) extends zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val ruleGroups: Optional[
      List[zio.aws.waf.model.SubscribedRuleGroupSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.ruleGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.waf.model.SubscribedRuleGroupSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListSubscribedRuleGroupsResponse
  ): zio.aws.waf.model.ListSubscribedRuleGroupsResponse.ReadOnly = new Wrapper(
    impl
  )
}
